# flutter_svg_test

### Testing

This package provides a set of functions to find images generated by
[**flutter_svg**  ](https://github.com/dnfield/flutter_svg/tree/master/packages/flutter_svg)
in widget tests.

The methods find elements with the `SvgPicture` type and compare either the `BytesLoader` or the
configuration of the `BytesLoader` with the giving test attribute.

### Example

#### Find by BytesLoader

The following example shows how you can find svgs with the matching `SvgAssetLoader`.

 ```dart
testWidgets('Finds svg', (WidgetTester widgetTester) async {
  
  final SvgPicture asset = SvgPicture.asset('/test/path/my.svg');
  
  await widgetTester.pumpWidget(asset);
  
  expect(find.svg(asset.bytesLoader), findsOneWidget);
});
```

#### Find by svg path

Sometimes it is more convenient instead of instantiate the whole `BytesLoader` to 
compare only specific attributes.

The following example shows how you can find svgs with the specified attribute.

 ```dart
testWidgets('asset svg with path', (WidgetTester widgetTester) async {
  const String svgPath = 'test/flutter_logo.svg';
  
  await widgetTester.pumpWidget(SvgPicture.asset(svgPath));
  
  expect(find.svgAssetWithPath(svgPath), findsOneWidget);
});
 ```
